.. -*-restructuredtext-*-

.. image:: https://travis-ci.org/ubernostrum/django-registration.svg?branch=master
    :target: https://travis-ci.org/ubernostrum/django-registration

This is a user-registration application for `Django
<https://www.djangoproject.com/>`_. There are two registration
workflows (one-step, and two-step with activation) built in, and it's
designed to be extensible and support building additional workflows.

To get started, check out `the documentation
<https://django-registration.readthedocs.io/>`_.
